// -*- c++ -*-
// Generated by gmmproc 2.46.1 -- DO NOT MODIFY!
#ifndef _GTKSOURCEVIEWMM_COMPLETIONINFO_P_H
#define _GTKSOURCEVIEWMM_COMPLETIONINFO_P_H


#include <gtkmm/private/window_p.h>

#include <glibmm/class.h>

namespace Gsv
{

class CompletionInfo_Class : public Glib::Class
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef CompletionInfo CppObjectType;
  typedef GtkSourceCompletionInfo BaseObjectType;
  typedef GtkSourceCompletionInfoClass BaseClassType;
  typedef Gtk::Window_Class CppClassParent;
  typedef GtkWindowClass BaseClassParent;

  friend class CompletionInfo;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  const Glib::Class& init();


  static void class_init_function(void* g_class, void* class_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.
#ifndef GTKSOURCEVIEWMM_DISABLE_DEPRECATED

  static void before_show_callback(GtkSourceCompletionInfo* self);
#endif // GTKSOURCEVIEWMM_DISABLE_DEPRECATED


  //Callbacks (virtual functions):
};


} // namespace Gsv


#endif /* _GTKSOURCEVIEWMM_COMPLETIONINFO_P_H */

